# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto.
Link para o curso [Python Pro](https://www.python.pro.br)

Suportado pela versão Python 3.

[![Build Status](https://travis-ci.com/ajesus92/libpythonpro.svg?branch=main)](https://travis-ci.com/ajesus92/libpythonpro)
[![Updates](https://pyup.io/repos/github/ajesus92/libpythonpro/shield.svg)](https://pyup.io/repos/github/ajesus92/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/ajesus92/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/ajesus92/libpythonpro/)

Para instalar:
```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código:
```console
flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip